# Tracks Registry

| Status | Track ID | Title | Created | Updated |
| ------ | -------- | ----- | ------- | ------- |
| [ ] | hsbk-rgb-float_20260318 | Update HSBK RGB Conversion to Float | 2026-03-18 | 2026-03-18 |

<!-- Tracks registered by /conductor:new-track -->
